import { CfnMicrosoftAD } from 'aws-cdk-lib/aws-directoryservice';
import { IVpc, SubnetSelection } from 'aws-cdk-lib/aws-ec2';
import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
import { Construct } from 'constructs';
/**
 * Properties for MicrosoftAD
 */
export interface MicrosoftADProps {
    /**
     * The fully qualified domain name for the AD directory (e.g. corp.example.com)
     */
    readonly domainName: string;
    /**
     * The password for the directory administrator
     */
    /**
     * The password for the directory administrator.
     * If not provided, a secure random password will be generated.
     *
     * @default - A secure random password is generated
     */
    readonly password?: Secret;
    /**
     * VPC where the Microsoft AD will be created
     */
    readonly vpc: IVpc;
    /**
     * Edition of Microsoft AD (Standard or Enterprise)
     * @default Standard
     */
    readonly edition?: 'Standard' | 'Enterprise';
    /**
     * Short name for the directory (e.g. CORP)
     * @default - derived from domain name
     */
    readonly shortName?: string;
    /**
     * @default - Two subnets will be selected from different AZs
     */
    readonly vpcSubnets?: SubnetSelection;
    /**
     * Enable Directory Data Service Access
     * @default false
     */
    readonly enableDirectoryDataAccess?: boolean;
    /**
     * Register AD with WorkSpaces
     * @default false
     */
    readonly registerWithWorkSpaces?: boolean;
}
/**
 * L2 Construct for AWS Managed Microsoft AD
 */
export declare class MicrosoftAD extends Construct {
    /**
     * The underlying CfnMicrosoftAD resource
     */
    readonly directory: CfnMicrosoftAD;
    /**
     * The ID of the directory
     */
    readonly directoryId: string;
    /**
     * The DNS addresses of the directory
     */
    readonly dnsIps: string[];
    /**
     * The secret containing the directory administrator password
     */
    readonly secretArn: string;
    constructor(scope: Construct, id: string, props: MicrosoftADProps);
}
